# pandas_toolkit

A collection of pandas accessors to help with common machine/deep learning related functionality.

[Documentation](https://asmith26.github.io/pandas_toolkit/), [PyPi](https://pypi.org/project/pandas-toolkit/)

## Installation

```bash
pip install pandas_toolkit
```

Or for additional interactive neural network learning plots:

```bash
pip install pandas_toolkit[streamz]
```
